@@ -1,5 +1,5 @@
 import yaml
-
+import json
 
 def create_yaml(data, f):
     try:
@@ -22,6 +22,16 @@ def read_yaml(f):
             return res
 
 
+def read_json(f):
+    try:
+        with open(f, 'r') as file:
+            data = json.load(file)
+    except Exception as e:
+        print("error while reading the json file: ", e.args)
+    else:
+        return data
+
+
 def extract_params(config):
     assert 'model' in config.keys(), "model parameters need to be provided in the yaml file"
     assert 'target' in config.keys(), "target variable needs to be provided in the yaml file"
